nature.oracle

Fixed-reference evaluation for independently scored species.

Fixed-reference evaluation for independently scored species.
raw docstring

evaluateclj/s

(evaluate populations fitness-fns references credit-fn generation)

Score every live individual once; fixed references never receive focal credit.

Score every live individual once; fixed references never receive focal credit.
sourceraw docstring

validate-optionsclj/s

(validate-options species-ids
                  {:keys [oracle-fitness-fns oracle-reference-metadata
                          final-evaluation-fn]
                   :as options})

Validate species callbacks, fixed reference metadata, and final pair evaluation.

Validate species callbacks, fixed reference metadata, and final pair evaluation.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries